/**
 * 5.2.6
 * Address
 */
declare type Address = {
    /** Identifies the nature of the address. */
    addressType: AddressTypeCode;
    /** Identification of a division of a large organisation or building. */
    department?: string;
    /** Identification of a sub-division of a large organisation or building. */
    subDepartment?: string;
    /** Name of a street or thoroughfare. */
    streetName?: string;
    /** Number that identifies the position of a building on a street. */
    buildingNumber?: string;
    /** Name of the building or house. */
    buildingName?: string;
    /** Floor or storey within a building. */
    floor?: string;
    /** Numbered box in a post office. */
    postBox?: string;
    /** Building room number. */
    room?: string;
    /** Identifier consisting of a group of letters and/or numbers that is added to a postal address to assist the sorting of mail. */
    postcode?: string;
    /** Name of a built-up area, with defined boundaries, and a local government. */
    townName: string;
    /** Specific location name within the town. */
    townLocationName?: string;
    /** Identifies a subdivision within a country subdivision. */
    districtName?: string;
    /** Identifies a subdivision of a country such as state, region, province. */
    countrySubDivision?: string;
    /** Information that locates and identifies a specific address, presented in free format text. */
    addressLine?: string[];
    /** Nation with its own government. */
    country: string;
};

/**
 * 5.3.11
 * AddressTypeCode
 *
 * `HOME` Residential - Address is the home address.
 * `BIZZ` Business - Address is the business address.
 * `GEOG` Geographic - Address is the unspecified physical (geographical) address suitable for identification of the natural or legal person.
 */
declare type AddressTypeCode = 'HOME' | 'BIZZ' | 'GEOG';

/**
 * Who is the agent acting on behalf of the counterparty
 * @public
 */
export declare interface Agent {
    did: DID;
    type: AgentType;
    logo?: string;
    url?: string;
    name?: string;
    verified?: boolean;
}

/**
 * The type of Agent. Either a wallet or a VASP
 * @public
 */
export declare enum AgentType {
    PRIVATE = "WALLET",
    VASP = "VASP"
}

/**
 * 6.3
 * The beneficiary is defined in Section 1.1 as the natural or legal person or legal arrangement who is identified by the originator as the receiver of the requested VA transfer.
 */
declare type Beneficiary = {
    beneficiaryPersons?: Person[];
    accountNumber?: string[];
};

declare type BeneficiaryFields = {
    destination?: destination;
};

/**
 * 6.5
 * The originating VASP is defined in Section 1.1 as the VASP which initiates the VA transfer, and transfers the VA upon receiving the request for a VA transfer on behalf of the originator.
 */
declare type BeneficiaryVASP = {
    beneficiaryVASP?: Person;
};

declare type BlockchainAddress = string;

declare type CAIP10 = `${CAIP2}:${string}`;

declare type CAIP19 = `${CAIP2}/${string}:${string}`;

declare type CAIP2 = `${string}:${string}`;

declare interface CallbackOptions {
    callback?: URI;
    redirectUri?: URI;
}

declare type Cancel = {
    type: CMType.CANCEL;
};

declare type CloseModal = {
    type: CMType.CLOSE;
    reqid: RequestID;
};

/**
 * Component Message Types
 * @internal
 */
export declare const enum CMType {
    COMPLETE = "complete",
    RESIZE = "resize",
    RESULT = "result",
    READY = "ready",
    INVALID = "invalid",
    MODAL = "openModal",
    ERROR = "error",
    CLOSE = "closeModal",
    CANCEL = "cancel"
}

declare type Completed = {
    type: CMType.COMPLETE;
    response: TransactionResponse;
};

/**
 * Component Message
 * @internal
 */
export declare type ComponentMessage = Completed | Cancel | Error_2 | Result | Ready | ResizeRequest | ModalRequest | InvalidValue | CloseModal;

/**
 * The counterparty of a transaction.
 * @public
 */
export declare interface Counterparty {
    name?: string;
    accountNumber?: string;
    did?: string;
    geographicAddress?: string;
    type?: PersonType;
    verified?: boolean;
}

declare type CryptoCredential = `${string}.${string}.mastercard`;

/**
 * 5.2.7
 * DateAndPlaceOfBirth
 */
declare type DateAndPlaceOfBirth = {
    dateOfBirth?: string;
    placeOfBirth?: string;
};

/**
 * Ownership Proof using Self Declaration
 * @public
 */
export declare interface DeclarationProof extends OwnershipProof {
    type: ProofTypes.SelfDeclaration;
    attestation: string;
    confirmed: boolean;
}

/**
 * An object representing a deposit transaction
 * @public
 */
export declare interface Deposit extends OriginatorFields, Transaction {
}

/**
 * An object representing a request for a deposit
 * @public
 */
export declare interface DepositRequest extends DepositRequestFields, Transaction {
}

declare type DepositRequestFields = {
    destinations: destination[];
};

/**
 * The destination of a transaction either a blockchain address, a CAIP-19 address, or a travel address.
 * @public
 */
export declare type destination = BlockchainAddress | CAIP10 | CryptoCredential | TravelAddress;

declare type DID = `did:${string}:${string}`;

declare type DTI = string;

/**
 * An embedded Notabene component
 * @public
 */
export declare class EmbeddedComponent {
    private _url;
    private _value;
    private _errors;
    private iframe?;
    private eventManager;
    private ready;
    private modal?;
    constructor(url: string, value: Partial<Transaction>);
    get url(): string;
    get value(): Partial<Transaction>;
    get errors(): ValidationError[];
    open(): void;
    mount(parentId: string): void;
    embed(parent: Element): void;
    send(message: HostMessage): void;
    on(messageType: string, callback: MessageCallback): void;
    off(messageType: string, callback: MessageCallback): void;
    update(value: Partial<Transaction>): void;
    completion(): Promise<TransactionResponse>;
    openModal(): void;
    private closeModal;
}

declare type Error_2 = {
    type: CMType.ERROR;
    message: string;
};

/**
 * Host Message Types
 * @internal
 */
declare const enum HMType {
    UPDATE = "update",
    REQUEST_RESPONSE = "requestResponse"
}

/**
 * Host Messages
 * @internal
 */
export declare type HostMessage = UpdateValue | RequestResponse;

/**
 * 5.2.13
 * IntermediaryVASP
 */
declare type IntermediaryVASP = {
    intermediaryVASP?: Person;
    sequence?: number;
};

declare type InvalidValue = {
    type: CMType.INVALID;
    value: any;
    errors: ValidationError[];
};

/**
 * IVMS101 definition
 *
 * @public
 */
export declare type IVMS101 = {
    originator?: Originator;
    beneficiary?: Beneficiary;
    originatingVASP?: OriginatingVASP;
    beneficiaryVASP?: BeneficiaryVASP;
    transferPath?: TransferPath;
    payloadMetadata?: PayloadMetadata;
};

/**
 * 5.2.9
 * LegalPerson
 */
declare type LegalPerson = {
    /** The name of the legal person. */
    name: LegalPersonName;
    /** The address of the legal person. */
    geographicAddress?: Address[];
    /** A distinct identifier that uniquely identifies the person to the institution in context. */
    customerNumber?: string;
    /** A distinct identifier used by governments to uniquely identify a legal person. */
    nationalIdentification?: NationalIdentification;
    /** The country in which the legal person is registered. */
    countryOfRegistration?: string;
};

/**
 * 5.2.10
 * LegalPersonName
 */
declare type LegalPersonName = {
    nameIdentifier: LegalPersonNameID[];
    localNameIdentifier?: LocalLegalPersonNameID[];
    phoneticNameIdentifier?: LocalLegalPersonNameID[];
};

/**
 * 5.2.11
 * LegalPersonNameID
 */
declare type LegalPersonNameID = {
    /** Name by which the legal person is known. */
    legalPersonName: string;
    /** The nature of the name specified. */
    legalPersonNameIdentifierType: LegalPersonNameTypeCode;
};

/**
 * 5.3.9
 * LegalPersonNameTypeCode
 *
 * `LEGL` Legal name - Official name under which an organisation is registered.
 * `SHRT` Short name - Specifies the short name of the organisation.
 * `TRAD` Trading name - Name used by a business for commercial purposes, although its registered legal name, used for contracts and other formal situations, may be another.
 */
declare type LegalPersonNameTypeCode = 'LEGL' | 'SHRT' | 'TRAD';

/**
 * 5.2.12
 * LocalLegalPersonNameID
 */
declare type LocalLegalPersonNameID = {
    legalPersonName?: string;
    legalPersonNameIdentifierType?: LegalPersonNameTypeCode;
};

/**
 * 5.2.5
 * LocalNaturalPersonNameID
 */
declare type LocalNaturalPersonNameID = {
    primaryIdentifier?: string;
    secondaryIdentifier?: string;
    nameIdentifierType?: NaturalPersonNameTypeCode;
};

declare type MessageCallback = (message: ComponentMessage) => void;

/**
 * Ownership Proof using Micro Transfer
 * @public
 */
export declare interface MicroTransferProof extends OwnershipProof {
    type: ProofTypes.MicroTransfer;
    txhash: string;
    chain: CAIP2;
    amount: number;
}

declare type ModalRequest = {
    type: CMType.MODAL;
    url: string;
    reqid: RequestID;
};

/**
 * 5.2.8
 * NationalIdentification
 */
declare type NationalIdentification = {
    nationalIdentifier?: string;
    nationalIdentifierType?: NationalIdentifierTypeCode;
    countryOfIssue?: string;
    registrationAuthority?: string;
};

/**
 * 5.3.14
 * NationalIdentifierTypeCode
 *
 * `ARNU` Alien registration number - Number assigned by a government agency to identify foreign nationals.
 * `CCPT` Passport number - Number assigned by a passport authority.
 * `RAID` Registration authority identifier - Identifier of a legal entity as maintained by a registration authority.
 * `DRLC` Driver license number - Number assigned to a driver's license.
 * `FIIN` Foreign investment identity number - Number assigned to a foreign investor (other than the alien number).
 * `TXID` Tax identification number - Number assigned by a tax authority to an entity.
 * `SOCS` Social security number - Number assigned by a social security agency.
 * `IDCD` Identity card number - Number assigned by a national authority to an identity card.
 * `LEIX` Legal Entity Identifier - Legal Entity Identifier (LEI) assigned in accordance with ISO 17442 11 .
 * `MISC` Unspecified - A national identifier which may be known but which cannot otherwise be categorized or the category of which the sender is unable to determine.
 */
declare type NationalIdentifierTypeCode = 'ARNU' | 'CCPT' | 'RAID' | 'DRLC' | 'FIIN' | 'TXID' | 'SOCS' | 'IDCD' | 'LEIX' | 'MISC';

/**
 * 5.2.2
 * NaturalPerson
 */
declare type NaturalPerson = {
    /** The distinct words used as identification for an individual. */
    name: NaturalPersonName;
    /** The particulars of a location at which a person may be communicated with. */
    geographicAddress?: Address[];
    /** A distinct identifier used by governments to uniquely identify a natural person. */
    nationalIdentification?: NationalIdentification;
    /** A distinct identifier that uniquely identifies the person to the institution in context. */
    customerIdentification?: string;
    /** Date and place of birth of a person. */
    dateAndPlaceOfBirth?: DateAndPlaceOfBirth;
    /** Country in which a person resides (the place of a person's home). */
    countryOfResidence?: string;
};

/**
 * 5.2.3
 * NaturalPersonName
 */
declare type NaturalPersonName = {
    nameIdentifier?: NaturalPersonNameID[];
    localNameIdentifier?: LocalNaturalPersonNameID[];
    phoneticNameIdentifier?: LocalNaturalPersonNameID[];
};

/**
 * 5.2.4
 * NaturalPersonNameID
 */
declare type NaturalPersonNameID = {
    primaryIdentifier?: string;
    secondaryIdentifier?: string;
    nameIdentifierType?: NaturalPersonNameTypeCode;
};

/**
 * 5.3.8
 * NaturalPersonNameTypeCode
 *
 * `ALIA` Alias name  - A name other than the legal name by which a natural person is also known.
 * `BIRT` Name at birth - The name given to a natural person at birth.
 * `MAID` Maiden name - The original name of a natural person who has changed their name after marriage.
 * `LEGL` Legal name - The name that identifies a natural person for legal, official or administrative purposes.
 * `MISC` Unspecified - A name by which a natural person may be known but which cannot otherwise be categorized or the category of which the sender is unable to determine.
 */
declare type NaturalPersonNameTypeCode = 'ALIA' | 'BIRT' | 'MAID' | 'LEGL' | 'MISC';

/**
 * Primary constructor for Notabene UX elements
 *
 * @public
 */
declare class Notabene {
    private nodeUrl?;
    private authToken?;
    private uxUrl;
    private theme?;
    private locale?;
    constructor(config: NotabeneConfig);
    componentUrl(path: string, value: Partial<Transaction>, configuration?: TransactionOptions, callbacks?: CallbackOptions): string;
    createComponent(path: string, value: Partial<Transaction>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponent;
    createWithdrawalAssist(value: Partial<Withdrawal>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponent;
    createDepositAssist(value: Partial<Deposit>, options?: any, callbacks?: CallbackOptions): EmbeddedComponent;
    createConnect(value: Partial<Withdrawal>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponent;
    createDepositRequest(value: Partial<DepositRequest>, options?: TransactionOptions, callbacks?: CallbackOptions): EmbeddedComponent;
    decodeFragmentToObject(fragment: string): Record<string, string>;
}
export { Notabene }
export default Notabene;

declare type NotabeneAsset = string;

/**
 * Configuration for the Notabene SDK
 *
 * @public
 */
export declare interface NotabeneConfig {
    nodeUrl?: string;
    authToken?: string;
    uxUrl?: string;
    theme?: Theme;
    locale?: string;
}

/**
 * 6.4
 * The originating VASP is defined in Section 1.1 as the VASP which initiates the VA transfer, and transfers the VA upon receiving the request for a VA transfer on behalf of the originator.
 */
declare type OriginatingVASP = {
    originatingVASP?: Person;
};

/**
 * 6.2
 * The originator is defined in Section 1.1 as the account holder who allows the VA transfer from that account or, where there is no account, the natural or legal person that places the order with the originating VASP to perform the VA transfer.
 */
declare type Originator = {
    originatorPersons?: Person[];
    accountNumber?: string[];
};

declare type OriginatorFields = {
    source?: Source;
};

/**
 * Ownership Proof
 * @public
 */
export declare interface OwnershipProof {
    type: ProofTypes;
    status: ProofStatus;
    did: DID;
    address: CAIP10;
}

/**
 * 6.7
 * Data describing the contents of the payload.
 */
declare interface PayloadMetadata {
    /** The method used to map from a national system of writing to Latin script. */
    transliterationMethod?: TransliterationMethodCode[];
    /** The version of IVMS 101 to which the payload complies. */
    payloadVersion: PayloadVersionCode;
}

/**
 * The version of IVMS 101 to which the payload complies.
 */
declare enum PayloadVersionCode {
    /** Published May 2020 */
    V101 = "101",
    /** Published August 2023 */
    V101_2023 = "101.2023"
}

/**
 * 5.2.1
 * Person
 */
declare type Person = {
    naturalPerson?: NaturalPerson;
    legalPerson?: LegalPerson;
};

/**
 * The type of counterparty. Either a natural person or a legal person. If the customer is the same as the counterparty then the counterparty is a self.
 * @public
 */
export declare enum PersonType {
    NATURAL = "natural",
    LEGAL = "legal",
    SELF = "self"
}

/**
 * Status of the proof
 * @public
 */
export declare enum ProofStatus {
    PENDING = "pending",// Verification is pending
    FAILED = "rejected",// Rejected
    FLAGGED = "flagged",// Flagged for manual review
    VERIFIED = "verified"
}

/**
 * The type of Proofs supported
 * @public
 **/
export declare enum ProofTypes {
    SelfDeclaration = "self-declaration",
    PersonalSignEIP191 = "eip-191",
    PersonalSignEIP712 = "eip-712",
    PersonalSignBIP137 = "bip-137",
    PersonalSignXPUB = "xpub",
    MicroTransfer = "microtransfer",
    Screenshot = "screenshot"
}

declare type Ready = {
    type: CMType.READY;
};

declare type RequestID = string;

declare type RequestResponse = {
    type: HMType.REQUEST_RESPONSE;
    reqid: RequestID;
};

declare type ResizeRequest = {
    type: CMType.RESIZE;
    height: number;
};

declare type Result = {
    type: CMType.RESULT;
    reqid: RequestID;
    response: TransactionResponse;
};

/**
 * Ownership Proof using Screenshot
 * @public
 */
export declare interface ScreenshotProof extends OwnershipProof {
    type: ProofTypes.Screenshot;
    url: string;
}

/**
 * Ownership Proof using Message Signature
 * @public
 */
export declare interface SignatureProof extends OwnershipProof {
    type: ProofTypes.PersonalSignEIP191 | ProofTypes.PersonalSignEIP712 | ProofTypes.PersonalSignBIP137 | ProofTypes.PersonalSignXPUB;
    proof: string;
    attestation: string;
    wallet_provider: string;
}

declare type Source = BlockchainAddress | CAIP10;

/**
 * The verification status of a transaction
 * @public
 */
export declare enum Status {
    EMPTY = "empty",
    VERIFY = "verify",
    PENDING = "pending",
    VERIFIED = "verified",
    BANNED = "banned"
}

/**
 * The theme of the Notabene SDK
 * @public
 */
export declare type Theme = {
    primaryColor: string;
    secondaryColor: string;
    fontFamily: string;
    logo: string;
};

/**
 * An abstract transaction object
 * @public
 */
export declare interface Transaction {
    agent: Agent;
    customer?: Counterparty;
    counterparty: Counterparty;
    asset: TransactionAsset;
    amountDecimal: number;
    customAssetPrice?: {
        price: number;
        currency: string;
    };
}

/**
 * The asset of a transaction either a Notabene asset, a CAIP-19 asset, or a DTI.
 *
 * @public
 */
export declare type TransactionAsset = NotabeneAsset | CAIP19 | DTI;

/**
 * Configuration options for Transaction components
 * @public
 */
export declare interface TransactionOptions {
    microTransactionAddress?: BlockchainAddress;
    proofFallbacks?: ProofTypes[];
}

/**
 * The response of a transaction
 * @public
 */
export declare type TransactionResponse = {
    value: Transaction;
    ivms: IVMS101;
    proof?: OwnershipProof;
    valid: boolean;
    status: Status;
    errors: ValidationError[];
    txCreate?: V1Transaction;
};

/**
 * 6.6
 * The transfer path refers to the intermediary VASP(s) participating in a serial chain that receive(s) and retransmit(s) a VA transfer on behalf of the originating VASP and the beneficiary VASP, or another intermediary VASP, together with their corresponding sequence number.
 */
declare type TransferPath = {
    transferPath?: IntermediaryVASP[];
};

/**
 * 5.3.16
 * TransliterationMethodCode
 *
 * `arab` Arabic (Arabic language) - ISO 233-2:1993
 * `aran` Arabic (Persian language) - ISO 233-3:1999
 * `armn` Armenian - ISO 9985:1996
 * `cyrl` Cyrillic - ISO 9:1995
 * `deva` Devanagari & related Indic - ISO 15919:2001
 * `geor` Georgian - ISO 9984:1996
 * `grek` Greek - ISO 843:1997
 * `hani` Han (Hanzi, Kanji, Hanja) - ISO 7098:2015
 * `hebr` Hebrew - ISO 259-2:1994
 * `kana` Kana - ISO 3602:1989
 * `kore` Korean - Revised Romanization of Korean
 * `thai` Thai - ISO 11940-2:2007
 * `othr` Script other than those listed above - Unspecified
 */
declare type TransliterationMethodCode = 'arab' | 'aran' | 'armn' | 'cyrl' | 'deva' | 'geor' | 'grek' | 'hani' | 'hebr' | 'kana' | 'kore' | 'thai' | 'othr';

declare type TravelAddress = `ta${string}`;

declare type UpdateValue = {
    type: HMType.UPDATE;
    value: Partial<Transaction>;
};

declare type URI = string;

declare type V1Asset = {
    caip19: CAIP19;
} | string;

/**
 * Transaction payload suitable for calling Notabene v1 tx/create
 * @public
 */
declare type V1Transaction = {
    transactionAsset: V1Asset;
    transactionAmount: string;
    originatorEqualsBeneficiary?: boolean;
    originatorVASPdid: DID;
    beneficiaryVASPdid: DID;
    beneficiaryProof: OwnershipProof;
    originator: Originator;
    beneficiary: Beneficiary;
};

declare type ValidationError = {
    attribute: string;
    message: string;
};

/**
 * A VASP agent acting on behalf of the counterparty
 * @public
 */
export declare interface VASP extends Agent {
    url?: string;
    name?: string;
}

/**
 * A wallet agent acting on behalf of the counterparty
 * @public
 */
export declare interface Wallet extends Agent {
    proof: OwnershipProof;
    wallet_connect_id?: string;
}

/**
 * An object representing a withdrawal transaction
 * @public
 */
export declare interface Withdrawal extends BeneficiaryFields, Transaction {
}

export { }
