/**
 * 5.3.8
 * NaturalPersonNameTypeCode
 *
 * `ALIA` Alias name  - A name other than the legal name by which a natural person is also known.
 * `BIRT` Name at birth - The name given to a natural person at birth.
 * `MAID` Maiden name - The original name of a natural person who has changed their name after marriage.
 * `LEGL` Legal name - The name that identifies a natural person for legal, official or administrative purposes.
 * `MISC` Unspecified - A name by which a natural person may be known but which cannot otherwise be categorized or the category of which the sender is unable to determine.
 */
export type NaturalPersonNameTypeCode =
  | 'ALIA'
  | 'BIRT'
  | 'MAID'
  | 'LEGL'
  | 'MISC';

/**
 * 5.3.9
 * LegalPersonNameTypeCode
 *
 * `LEGL` Legal name - Official name under which an organisation is registered.
 * `SHRT` Short name - Specifies the short name of the organisation.
 * `TRAD` Trading name - Name used by a business for commercial purposes, although its registered legal name, used for contracts and other formal situations, may be another.
 */
export type LegalPersonNameTypeCode = 'LEGL' | 'SHRT' | 'TRAD';

/**
 * 5.3.11
 * AddressTypeCode
 *
 * `HOME` Residential - Address is the home address.
 * `BIZZ` Business - Address is the business address.
 * `GEOG` Geographic - Address is the unspecified physical (geographical) address suitable for identification of the natural or legal person.
 */
export type AddressTypeCode = 'HOME' | 'BIZZ' | 'GEOG';

/**
 * 5.3.14
 * NationalIdentifierTypeCode
 *
 * `ARNU` Alien registration number - Number assigned by a government agency to identify foreign nationals.
 * `CCPT` Passport number - Number assigned by a passport authority.
 * `RAID` Registration authority identifier - Identifier of a legal entity as maintained by a registration authority.
 * `DRLC` Driver license number - Number assigned to a driver's license.
 * `FIIN` Foreign investment identity number - Number assigned to a foreign investor (other than the alien number).
 * `TXID` Tax identification number - Number assigned by a tax authority to an entity.
 * `SOCS` Social security number - Number assigned by a social security agency.
 * `IDCD` Identity card number - Number assigned by a national authority to an identity card.
 * `LEIX` Legal Entity Identifier - Legal Entity Identifier (LEI) assigned in accordance with ISO 17442 11 .
 * `MISC` Unspecified - A national identifier which may be known but which cannot otherwise be categorized or the category of which the sender is unable to determine.
 */
export type NationalIdentifierTypeCode =
  | 'ARNU'
  | 'CCPT'
  | 'RAID'
  | 'DRLC'
  | 'FIIN'
  | 'TXID'
  | 'SOCS'
  | 'IDCD'
  | 'LEIX'
  | 'MISC';

/**
 * 5.3.16
 * TransliterationMethodCode
 *
 * `arab` Arabic (Arabic language) - ISO 233-2:1993
 * `aran` Arabic (Persian language) - ISO 233-3:1999
 * `armn` Armenian - ISO 9985:1996
 * `cyrl` Cyrillic - ISO 9:1995
 * `deva` Devanagari & related Indic - ISO 15919:2001
 * `geor` Georgian - ISO 9984:1996
 * `grek` Greek - ISO 843:1997
 * `hani` Han (Hanzi, Kanji, Hanja) - ISO 7098:2015
 * `hebr` Hebrew - ISO 259-2:1994
 * `kana` Kana - ISO 3602:1989
 * `kore` Korean - Revised Romanization of Korean
 * `thai` Thai - ISO 11940-2:2007
 * `othr` Script other than those listed above - Unspecified
 */
export type TransliterationMethodCode =
  | 'arab'
  | 'aran'
  | 'armn'
  | 'cyrl'
  | 'deva'
  | 'geor'
  | 'grek'
  | 'hani'
  | 'hebr'
  | 'kana'
  | 'kore'
  | 'thai'
  | 'othr';

/**
 * 5.2.8
 * NationalIdentification
 */
export type NationalIdentification = {
  nationalIdentifier?: string; //Max35Text
  nationalIdentifierType?: NationalIdentifierTypeCode;
  countryOfIssue?: string; //CountryCode (^[A-Z]{2}$)
  registrationAuthority?: string; //RegistrationAuthority (^RA([0-9]{6})$)
};

/**
 * 5.2.7
 * DateAndPlaceOfBirth
 */
export type DateAndPlaceOfBirth = {
  dateOfBirth?: string; //YYYY-MM-DD
  placeOfBirth?: string; //Max70Text
};

/**
 * 5.2.6
 * Address
 */
export type Address = {
  /** Identifies the nature of the address. */
  addressType: AddressTypeCode;
  /** Identification of a division of a large organisation or building. */
  department?: string;
  /** Identification of a sub-division of a large organisation or building. */
  subDepartment?: string;
  /** Name of a street or thoroughfare. */
  streetName?: string;
  /** Number that identifies the position of a building on a street. */
  buildingNumber?: string;
  /** Name of the building or house. */
  buildingName?: string;
  /** Floor or storey within a building. */
  floor?: string;
  /** Numbered box in a post office. */
  postBox?: string;
  /** Building room number. */
  room?: string;
  /** Identifier consisting of a group of letters and/or numbers that is added to a postal address to assist the sorting of mail. */
  postcode?: string;
  /** Name of a built-up area, with defined boundaries, and a local government. */
  townName: string;
  /** Specific location name within the town. */
  townLocationName?: string;
  /** Identifies a subdivision within a country subdivision. */
  districtName?: string;
  /** Identifies a subdivision of a country such as state, region, province. */
  countrySubDivision?: string;
  /** Information that locates and identifies a specific address, presented in free format text. */
  addressLine?: string[];
  /** Nation with its own government. */
  country: string;
};

/**
 * 5.2.5
 * LocalNaturalPersonNameID
 */
export type LocalNaturalPersonNameID = {
  primaryIdentifier?: string; //LocalMax100Text
  secondaryIdentifier?: string; //LocalMax100Text
  nameIdentifierType?: NaturalPersonNameTypeCode;
};

/**
 * 5.2.4
 * NaturalPersonNameID
 */
export type NaturalPersonNameID = {
  primaryIdentifier?: string; //Max100Text
  secondaryIdentifier?: string; //Max100Text
  nameIdentifierType?: NaturalPersonNameTypeCode;
};

/**
 * 5.2.3
 * NaturalPersonName
 */
export type NaturalPersonName = {
  nameIdentifier?: NaturalPersonNameID[];
  localNameIdentifier?: LocalNaturalPersonNameID[];
  phoneticNameIdentifier?: LocalNaturalPersonNameID[];
};

/**
 * 5.2.2
 * NaturalPerson
 */
export type NaturalPerson = {
  /** The distinct words used as identification for an individual. */
  name: NaturalPersonName;
  /** The particulars of a location at which a person may be communicated with. */
  geographicAddress?: Address[];
  /** A distinct identifier used by governments to uniquely identify a natural person. */
  nationalIdentification?: NationalIdentification;
  /** A distinct identifier that uniquely identifies the person to the institution in context. */
  customerIdentification?: string;
  /** Date and place of birth of a person. */
  dateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  /** Country in which a person resides (the place of a person's home). */
  countryOfResidence?: string;
};

/**
 * 5.2.12
 * LocalLegalPersonNameID
 */
export type LocalLegalPersonNameID = {
  legalPersonName?: string; //LocalMax100Text
  legalPersonNameIdentifierType?: LegalPersonNameTypeCode;
};

/**
 * 5.2.11
 * LegalPersonNameID
 */
export type LegalPersonNameID = {
  /** Name by which the legal person is known. */
  legalPersonName: string;
  /** The nature of the name specified. */
  legalPersonNameIdentifierType: LegalPersonNameTypeCode;
};

/**
 * 5.2.10
 * LegalPersonName
 */
export type LegalPersonName = {
  nameIdentifier: LegalPersonNameID[];
  localNameIdentifier?: LocalLegalPersonNameID[];
  phoneticNameIdentifier?: LocalLegalPersonNameID[];
};

/**
 * 5.2.9
 * LegalPerson
 */
export type LegalPerson = {
  /** The name of the legal person. */
  name: LegalPersonName;
  /** The address of the legal person. */
  geographicAddress?: Address[];
  /** A distinct identifier that uniquely identifies the person to the institution in context. */
  customerNumber?: string;
  /** A distinct identifier used by governments to uniquely identify a legal person. */
  nationalIdentification?: NationalIdentification;
  /** The country in which the legal person is registered. */
  countryOfRegistration?: string;
};

/**
 * 5.2.1
 * Person
 */
export type Person = {
  naturalPerson?: NaturalPerson;
  legalPerson?: LegalPerson;
};

/**
 * 5.2.13
 * IntermediaryVASP
 */
export type IntermediaryVASP = {
  intermediaryVASP?: Person;
  sequence?: number;
};

/**
 * 6.2
 * The originator is defined in Section 1.1 as the account holder who allows the VA transfer from that account or, where there is no account, the natural or legal person that places the order with the originating VASP to perform the VA transfer.
 */
export type Originator = {
  originatorPersons?: Person[];
  accountNumber?: string[]; //Max100Text
};

/**
 * 6.3
 * The beneficiary is defined in Section 1.1 as the natural or legal person or legal arrangement who is identified by the originator as the receiver of the requested VA transfer.
 */
export type Beneficiary = {
  beneficiaryPersons?: Person[];
  accountNumber?: string[]; //max100
};

/**
 * 6.4
 * The originating VASP is defined in Section 1.1 as the VASP which initiates the VA transfer, and transfers the VA upon receiving the request for a VA transfer on behalf of the originator.
 */
export type OriginatingVASP = {
  originatingVASP?: Person;
};

/**
 * 6.5
 * The originating VASP is defined in Section 1.1 as the VASP which initiates the VA transfer, and transfers the VA upon receiving the request for a VA transfer on behalf of the originator.
 */
export type BeneficiaryVASP = {
  beneficiaryVASP?: Person;
};

/**
 * 6.6
 * The transfer path refers to the intermediary VASP(s) participating in a serial chain that receive(s) and retransmit(s) a VA transfer on behalf of the originating VASP and the beneficiary VASP, or another intermediary VASP, together with their corresponding sequence number.
 */
export type TransferPath = {
  transferPath?: IntermediaryVASP[];
};

/**
 * 6.7
 * Data describing the contents of the payload.
 */
export interface PayloadMetadata {
  /** The method used to map from a national system of writing to Latin script. */
  transliterationMethod?: TransliterationMethodCode[];
  /** The version of IVMS 101 to which the payload complies. */
  payloadVersion: PayloadVersionCode;
}
/**
 * The version of IVMS 101 to which the payload complies.
 */
export enum PayloadVersionCode {
  /** Published May 2020 */
  V101 = '101',
  /** Published August 2023 */
  V101_2023 = '101.2023',
}

/**
 * IVMS101 definition
 *
 * @public
 */
export type IVMS101 = {
  originator?: Originator;
  beneficiary?: Beneficiary;
  originatingVASP?: OriginatingVASP;
  beneficiaryVASP?: BeneficiaryVASP;
  transferPath?: TransferPath;
  payloadMetadata?: PayloadMetadata;
};
